pub enum IncrementAxis {
Horizontal,
Vertical,
}Expand description
The address increment orientation when writing image data. This configures how the SSD1322 will
auto-increment the row and column addresses when image data is written using the
WriteImageData command.
Variants
Horizontal
The column address will increment as image data is written, writing pairs of bytes
(horizontal groups of 4 pixels) from left to right in the range set by SetColumnAddress
command, and then top to bottom in the range set by SetRowAddress command.
Vertical
The row address will increment as image data is written, writing pairs of bytes
(horizontal groups of 4 pixels) from top to bottom in the range set by SetRowAddress
command, and then left to right in the range set by SetColumnAddress command.